HardForkState

Struct HardForkState 

pub struct HardForkState {
    pub current_hardfork: HardFork,
    pub config: HardForkConfig,
    pub votes: HFVotes,
    pub last_height: usize,
}
A struct that keeps track of the current hard-fork and current votes.

Fields

current_hardfork: HardFork

The current active hard-fork.

config: HardForkConfig

The hard-fork config.

votes: HFVotes

The votes in the current window.

last_height: usize

The last block height accounted for.

Implementations

Source

impl HardForkState

pub async fn init_from_chain_height<D: Database + Clone>( chain_height: usize, config: HardForkConfig, database: D, ) -> Result<Self, ContextCacheError>

Initialize the HardForkState from the specified chain height.

pub async fn pop_blocks_main_chain<D: Database + Clone>( &mut self, numb_blocks: usize, database: D, ) -> Result<(), ContextCacheError>

Pop some blocks from the top of the cache.

The cache will be returned to the state it would have been in numb_blocks ago.

Invariant

This must only be used on a main-chain cache.

pub fn new_block(&mut self, vote: HardFork, height: usize)

Add a new block to the cache.

pub fn hardfork_infos(&self) -> Vec<HardForkInfo>

Returns info on all hard-forks.

pub const fn current_hardfork(&self) -> HardFork

Returns the current hard-fork.