pub struct HardForkState {
pub current_hardfork: HardFork,
pub config: HardForkConfig,
pub votes: HFVotes,
pub last_height: usize,
}Expand description
A struct that keeps track of the current hard-fork and current votes.
Fields
current_hardfork: HardForkThe current active hard-fork.
config: HardForkConfigThe hard-fork config.
votes: HFVotesThe votes in the current window.
last_height: usizeThe last block height accounted for.
Implementations
Sourceimpl HardForkState
impl HardForkState
Sourcepub async fn init_from_chain_height<D: Database + Clone>(
chain_height: usize,
config: HardForkConfig,
database: D,
) -> Result<Self, ContextCacheError>
pub async fn init_from_chain_height<D: Database + Clone>( chain_height: usize, config: HardForkConfig, database: D, ) -> Result<Self, ContextCacheError>
Initialize the HardForkState from the specified chain height.
Sourcepub async fn pop_blocks_main_chain<D: Database + Clone>(
&mut self,
numb_blocks: usize,
database: D,
) -> Result<(), ContextCacheError>
pub async fn pop_blocks_main_chain<D: Database + Clone>( &mut self, numb_blocks: usize, database: D, ) -> Result<(), ContextCacheError>
Pop some blocks from the top of the cache.
The cache will be returned to the state it would have been in numb_blocks ago.
Invariant
This must only be used on a main-chain cache.
Sourcepub fn hardfork_infos(&self) -> Vec<HardForkInfo>
pub fn hardfork_infos(&self) -> Vec<HardForkInfo>
Returns info on all hard-forks.
Sourcepub const fn current_hardfork(&self) -> HardFork
pub const fn current_hardfork(&self) -> HardFork
Returns the current hard-fork.